@@ -2,7 +2,7 @@
 Author: LetMeFly
 Date: 2022-01-24 15:01:27
 LastEditors: LetMeFly
-LastEditTime: 2022-01-26 11:00:58
+LastEditTime: 2022-02-21 17:12:04
 Description: 获取某场比赛的题面数量
 '''
 import requests
@@ -16,7 +16,9 @@ except:
 
 
 def getContestProblemList(cid: str, cookies='') -> int:
-    response = requests.get('http://182.92.175.181/contest.php?cid='+str(cid), cookies=cookies)
+    from . import Config
+    base_url = Config.get_info("base_url")
+    response = requests.get(f'{base_url}contest.php?cid='+str(cid), cookies=cookies)
     soup = BeautifulSoup(response.text, features)
     table = soup.find('table')
     return len(table.find('tbody').find_all('tr'))
